# AI-Bash: 智能命令行工具

本文档提供详细的使用说明、配置和开发指南。基本介绍请参阅[README.md](README.md)。

## 目录

- [详细配置](#详细配置)
- [平台支持](#平台支持)
- [开发指南](#开发指南)
- [发布流程](#发布流程)
- [常见问题](#常见问题)

## 详细配置

### 配置文件完整选项

在用户主目录下创建`.cmd_ai`文件:

```
# 必需的API密钥
OPENAI_API_KEY=你的OpenAI API密钥

# 可选的API主机地址(用于私有部署或国内镜像站)
# OPENAI_API_HOST=https://your-api-host.com/v1

# 可选的模型名称,默认为gpt-3.5-turbo
# OPENAI_MODEL_NAME=gpt-4
```

### 命令行高级选项

```bash
# 显示详细系统信息
ai_bash "查找大文件" --verbose

# 指定模型
ai_bash "列出所有进程" --model gpt-4

# 指定API地址(适用于私有部署或国内镜像站)
ai_bash "查找大文件" --api-host https://your-api-host.com/v1
```

## 平台支持

AI-Bash会自动检测当前环境并生成适合的命令:

- **Windows**: 支持CMD和PowerShell环境，生成适用于Windows的命令
- **Linux**: 支持各种Shell(Bash, Zsh等)和WSL环境，生成适用于Linux的命令
- **macOS**: 支持各种Shell(Bash, Zsh等)，生成适用于macOS的命令

## 开发指南

### 项目结构

```
ai_bash/
├── src/
│   └── cmd_ai/          # 主代码目录
│       ├── __init__.py  # 包初始化
│       ├── main.py      # 命令行入口
│       ├── config.py    # 配置管理
│       └── llm.py       # 大模型API调用
├── scripts/             # 辅助脚本
├── .github/             # GitHub配置
└── pyproject.toml       # 项目配置
```

## 发布流程

### 准备工作

1. 安装必要工具:
```bash
uv pip install build twine
```

2. 创建PyPI账号 (https://pypi.org/account/register/)

3. 创建API令牌:
   - 登录PyPI后访问"Account settings"
   - 在"API tokens"部分创建新令牌
   - 复制生成的令牌（离开页面后无法再次查看）

### 手动发布

1. 构建分发包:
```bash
python -m build
```

2. 上传到PyPI:
```bash
twine upload dist/*
```

### 通过GitHub Actions自动发布

可以通过以下三种方式触发自动发布:

1. **创建GitHub Release**:
   - 在GitHub仓库页面点击"Releases" > "Create a new release"
   - 填写版本号和发布说明
   - 点击"Publish release"

2. **推送到master分支**:
   - 每当推送到master或main分支时，会触发构建

3. **手动触发工作流**:
   - 在GitHub仓库页面点击"Actions"
   - 选择"发布到PyPI"工作流
   - 点击"Run workflow"并填写相关信息

### 发布前检查

发布前确保:
1. 包名可用（当前包名为`ai_bash`）
2. 版本号已更新
3. 测试通过

## 常见问题

### Q: OpenAI API密钥无效或不存在
A: 确保您已正确设置API密钥，可通过`--api-key`参数提供或在配置文件中设置。

### Q: 命令生成不正确
A: 使用`--verbose`查看系统环境信息，确保系统检测正确。尝试使用更高级的模型（如gpt-4）。

### Q: 安装后无法运行命令
A: 确保Python环境的bin目录在PATH中。可尝试重新安装或使用完整路径运行命令。 